@@ -30,7 +30,7 @@ namespace VLC {
 
 Media::Media(const QByteArray &mrl, QObject *parent) :
     QObject(parent),
-    m_media(libvlc_media_new_location(libvlc, mrl.constData())),
+    m_media(libvlc_media_new_location(pvlc_libvlc, mrl.constData())),
     m_mrl(mrl)
 {
     Q_ASSERT(m_media);
@@ -91,10 +91,6 @@ void Media::event_cb(const libvlc_event_t *event, void *opaque)
     case libvlc_MediaParsedChanged:
     case libvlc_MediaFreed:
     case libvlc_MediaStateChanged:
-    default:
-        break;
-        QString msg = QString("Unknown event: ") + QString(libvlc_event_type_name(event->type));
-        Q_ASSERT_X(false, "event_cb", qPrintable(msg));
         break;
     }
 }
