@@ -23,6 +23,11 @@
 #include <QtCore/QVariant>
 
 #include <vlc/libvlc.h>
+#include <vlc/libvlc_version.h>
+#if (LIBVLC_VERSION_INT >= LIBVLC_VERSION(4, 0, 0, 0))
+// Bit of a work around. media.h requires picture
+#include <vlc/libvlc_picture.h>
+#endif
 #include <vlc/libvlc_media.h>
 
 #define INTPTR_PTR(x) reinterpret_cast<intptr_t>(x)
@@ -35,7 +40,7 @@ class Media : public QObject
 {
     Q_OBJECT
 public:
-    explicit Media(const QByteArray &mrl, QObject *parent = 0);
+    explicit Media(const QByteArray &mrl, QObject *parent = nullptr);
     ~Media();
 
     inline libvlc_media_t *libvlc_media() const { return m_media; }
@@ -57,7 +62,9 @@ public:
 
     QString meta(libvlc_meta_t meta);
 
-signals:
+    void setCdTrack(int track);
+
+Q_SIGNALS:
     void durationChanged(qint64 duration);
     void metaDataChanged();
 
@@ -66,6 +73,7 @@ private:
 
     libvlc_media_t *m_media;
     libvlc_state_t m_state;
+    QByteArray m_mrl;
 };
 
 } // namespace VLC
