@@ -4,7 +4,7 @@
     Copyright (C) 2009 Fathi Boudra <fabo@kde.org>
     Copyright (C) 2010 Ben Cooksley <sourtooth@gmail.com>
     Copyright (C) 2009-2011 vlc-phonon AUTHORS <kde-multimedia@kde.org>
-    Copyright (C) 2010-2015 Harald Sitter <sitter@kde.org>
+    Copyright (C) 2010-2021 Harald Sitter <sitter@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -109,6 +109,10 @@ void MediaObject::resetMembers()
     m_stateAfterBuffering = ErrorState;
 
     resetMediaController();
+
+    // Forcefully shutdown plusesupport to prevent crashing between the PS PA glib mainloop
+    // and the VLC PA threaded mainloop. See destructor.
+    PulseSupport::shutdown();
 }
 
 void MediaObject::play()
@@ -239,7 +243,7 @@ void MediaObject::loadMedia(const QByteArray &mrl)
     debug() << "loading encoded:" << m_mrl;
 
     // We do not have a loading state generally speaking, usually the backend
-    // is exepected to go to loading state and then at some point reach stopped,
+    // is expected to go to loading state and then at some point reach stopped,
     // at which point playback can be started.
     // See state enum documentation for more information.
     changeState(Phonon::StoppedState);
@@ -310,7 +314,7 @@ void MediaObject::setSource(const MediaSource &source)
         m_streamReader->unlock();
         delete m_streamReader;
         m_streamReader = 0;
-        // For streamreaders we exchanage the player's seekability with the
+        // For streamreaders we exchange the player's seekability with the
         // reader's so here we change it back.
         // Note: the reader auto-disconnects due to destruction.
         connect(m_player, SIGNAL(seekableChanged(bool)), this, SIGNAL(seekableChanged(bool)));
@@ -349,16 +353,16 @@ void MediaObject::setSource(const MediaSource &source)
             error() << Q_FUNC_INFO << "the MediaSource::Disc doesn't specify which one (Phonon::NoDisc)";
             return;
         case Phonon::Cd:
-            loadMedia(QLatin1Literal("cdda://") % m_mediaSource.deviceName());
+            loadMedia(QStringLiteral("cdda://") % m_mediaSource.deviceName());
             break;
         case Phonon::Dvd:
-            loadMedia(QLatin1Literal("dvd://") % m_mediaSource.deviceName());
+            loadMedia(QStringLiteral("dvd://") % m_mediaSource.deviceName());
             break;
         case Phonon::Vcd:
-            loadMedia(QLatin1Literal("vcd://") % m_mediaSource.deviceName());
+            loadMedia(QStringLiteral("vcd://") % m_mediaSource.deviceName());
             break;
         case Phonon::BluRay:
-            loadMedia(QLatin1Literal("bluray://") % m_mediaSource.deviceName());
+            loadMedia(QStringLiteral("bluray://") % m_mediaSource.deviceName());
             break;
         }
         break;
@@ -376,7 +380,7 @@ void MediaObject::setSource(const MediaSource &source)
         deviceName = source.deviceAccessList().first().second;
 
         if (driverName == QByteArray("v4l2")) {
-            loadMedia(QLatin1Literal("v4l2://") % deviceName);
+            loadMedia(QStringLiteral("v4l2://") % deviceName);
         } else if (driverName == QByteArray("alsa")) {
             /*
              * Replace "default" and "plughw" and "x-phonon" with "hw" for capture device names, because
@@ -395,9 +399,9 @@ void MediaObject::setSource(const MediaSource &source)
                 deviceName.replace(0, 8, "hw");
             }
 
-            loadMedia(QLatin1Literal("alsa://") % deviceName);
+            loadMedia(QStringLiteral("alsa://") % deviceName);
         } else if (driverName == "screen") {
-            loadMedia(QLatin1Literal("screen://") % deviceName);
+            loadMedia(QStringLiteral("screen://") % deviceName);
 
             // Set the isScreen flag needed to add extra options in playInternal
             m_isScreen = true;
@@ -542,8 +546,6 @@ void MediaObject::setupMedia()
 
     // Create a media with the given MRL
     m_media = new Media(m_mrl, this);
-    if (!m_media)
-        error() << "libVLC:" << LibVLC::errorMessage();
 
     if (m_isScreen) {
         m_media->addOption(QLatin1String("screen-fps=24.0"));
