@@ -36,7 +36,7 @@
 
 #define DEBUG_INDENT_OBJECTNAME QLatin1String("Debug_Indent_object")
 
-QMutex Debug::mutex( QMutex::Recursive );
+QRecursiveMutex Debug::mutex;
 
 using namespace Debug;
 
@@ -228,5 +228,5 @@ Block::~Block()
 void Debug::stamp()
 {
     static int n = 0;
-    debug() << "| Stamp: " << ++n << endl;
+    debug() << "| Stamp: " << ++n << Qt::endl;
 }
