@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2012 Harald Sitter <sitter@kde.org>
+    Copyright (C) 2012-2021 Harald Sitter <sitter@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,16 @@
 #ifndef PHONON_VLC_VIDEOMEMORYSTREAM_H
 #define PHONON_VLC_VIDEOMEMORYSTREAM_H
 
+// VLC 3.0 uses the restrict keyword. restrict is not a thing in C++, so
+// depending on the compiler you use an extension keyword or drop it entirely.
+#if defined(Q_CC_GNU)
+#define restrict __restrict__
+#elif defined(Q_CC_MSVC)
+#define restrict __restrict
+#else
+#define restrict
+#endif
+
 #include <vlc/plugins/vlc_common.h>
 #include <vlc/plugins/vlc_fourcc.h>
 
@@ -31,14 +41,13 @@ class VideoMemoryStream
 public:
     explicit VideoMemoryStream();
     virtual ~VideoMemoryStream();
-    
+
     /**
      * @returns overall buffersize needed
      */
-    static unsigned setPitchAndLines(const vlc_chroma_description_t *chromaDescription,
+    static unsigned setPitchAndLines(uint32_t fourcc,
                                      unsigned width, unsigned height,
-                                     unsigned *pitches, unsigned *lines,
-                                     unsigned *visiblePitches = 0, unsigned *visibleLines = 0);
+                                     unsigned *pitches, unsigned *lines);
 
     void setCallbacks(Phonon::VLC::MediaPlayer *player);
     void unsetCallbacks(Phonon::VLC::MediaPlayer *player);
